==> deepin-log-viewer_5.9.7.orig.tar.xz: deepin-log-viewer-5.9.7/translations/deepin-log-viewer_hi_IN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hi_IN">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>फ़ाइल प्रबंधक में दिखाएँ</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>लॉग फ़ाइलें हटाएँ</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>रिफ्रेश करें</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>क्या आप सभी लॉग फ़ाइलें हटाना चाहते हैं?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>रद्द करें</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>पुष्टि करें</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>सभी</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>आज</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 दिन पूर्व</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 सप्ताह पूर्व</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 माह पूर्व</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 माह पूर्व</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">निर्यात करें</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>निर्यात करें</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>सभी</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>अति आवश्यक</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>संकटमय</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>विकट</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>त्रुटि</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>चेतावनी</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>सूचना</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>जानकारी</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>दोषमार्जन</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>लॉगिन</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>बूट</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>शटडाउन</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>अत्यंत विकट</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>ट्रेस</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>निर्यात जारी है...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>रद्द करें</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>निर्यात सफल</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>निर्यात विफल</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>फ़ाइल निर्यात करें</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>अवधि :</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>स्तर :</translation>
    </message>
    <message>
        <source>Application list:</source>
        <translation>अनुप्रयोग सूची :</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>स्थिति :</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>घटना का प्रकार :</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>उपयोक्ता :</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>कार्य :</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>उपयोक्ता नाम :</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>बूट रिकॉर्ड</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>शटडाउन रिकॉर्ड</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>लॉगिन रिकॉर्ड</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>चेतावनी</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>दोषमार्जन</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>जानकारी</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>त्रुटि</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>अति आवश्यक</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>संकटमय</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>विकट</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>सूचना</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>ट्रेस</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>अत्यंत विकट</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>लॉग फाइल रिक्त है</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>लॉग फ़ाइल प्रदर्शक</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>लॉग फ़ाइल प्रदर्शक सिस्टम लॉग देखने हेतु एक उपयोगी साधन है।</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>खोज का परिणाम नहीं मिला</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>खोजें</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>स्तर</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>प्रक्रिया</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>दिनांक व समय</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>जानकारी</translation>
    </message>
    <message>
        <source>User</source>
        <translation>उपयोक्ता</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>स्रोत</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>कार्य</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>स्थिति</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>घटना का प्रकार</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>उपयोक्ता नाम</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>स्तर :</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>प्रक्रिया :</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>दिनांक व समय :</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>जानकारी :</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>रिक्त</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>उपयोक्ता :</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>दिनांक व समय</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>सिस्टम लॉग</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>कर्नेल लॉग</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>बूट लॉग</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>dpkg लॉग</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Kwin लॉग</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Xorg लॉग</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>अनुप्रयोग लॉग</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>बूट-शटडाउन घटना</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>dnf लॉग</translation>
    </message>
</context>
</TS>

==> deepin-log-viewer_6.0.7.orig.tar.xz: deepin-log-viewer-6.0.7/translations/deepin-log-viewer_hi_IN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hi_IN">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>फ़ाइल प्रबंधक में दिखाएँ</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>लॉग फ़ाइलें हटाएँ</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>रिफ्रेश करें</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>क्या आप सभी लॉग फ़ाइलें हटाना चाहते हैं?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>रद्द करें</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>पुष्टि करें</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>सभी</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>आज</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 दिन पूर्व</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 सप्ताह पूर्व</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 माह पूर्व</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 माह पूर्व</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">निर्यात करें</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>निर्यात करें</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>सभी</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>अति आवश्यक</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>संकटमय</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>विकट</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>त्रुटि</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>चेतावनी</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>सूचना</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>जानकारी</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>दोषमार्जन</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>लॉगिन</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>बूट</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>शटडाउन</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>अत्यंत विकट</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>ट्रेस</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>निर्यात जारी है...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>रद्द करें</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>निर्यात सफल</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>निर्यात विफल</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>फ़ाइल निर्यात करें</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>अवधि :</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>स्तर :</translation>
    </message>
    <message>
        <source>Application list:</source>
        <translation>अनुप्रयोग सूची :</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>स्थिति :</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>घटना का प्रकार :</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>उपयोक्ता :</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>कार्य :</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>उपयोक्ता नाम :</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>बूट रिकॉर्ड</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>शटडाउन रिकॉर्ड</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>लॉगिन रिकॉर्ड</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>चेतावनी</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>दोषमार्जन</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>जानकारी</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>त्रुटि</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>अति आवश्यक</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>संकटमय</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>विकट</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>सूचना</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>ट्रेस</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>अत्यंत विकट</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>लॉग फाइल रिक्त है</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>लॉग फ़ाइल प्रदर्शक</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>लॉग फ़ाइल प्रदर्शक सिस्टम लॉग देखने हेतु एक उपयोगी साधन है।</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>खोज का परिणाम नहीं मिला</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>खोजें</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>स्तर</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>प्रक्रिया</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>दिनांक व समय</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>जानकारी</translation>
    </message>
    <message>
        <source>User</source>
        <translation>उपयोक्ता</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>स्रोत</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>कार्य</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>स्थिति</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>घटना का प्रकार</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>उपयोक्ता नाम</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>स्तर :</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>प्रक्रिया :</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>दिनांक व समय :</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>जानकारी :</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>रिक्त</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>उपयोक्ता :</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>File Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Time Modified</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>दिनांक व समय</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>सिस्टम लॉग</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>कर्नेल लॉग</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>बूट लॉग</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>dpkg लॉग</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Kwin लॉग</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Xorg लॉग</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>अनुप्रयोग लॉग</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>बूट-शटडाउन घटना</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>dnf लॉग</translation>
    </message>
    <message>
        <source>Other Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Custom Log</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Warning</name>
    <message>
        <source>You do not have permission to view it</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>10 sec</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>1 min</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>5 min</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No refresh</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export All</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System Logs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
